
Debug enabling
-------

**Description:**

Sometimes it is possible through an "enabling debug parameter" to display technical 
information within the application. As a result the attacker learns more about the 
operation of the application, increasing his attack vector.


**Solution:**

Disable the possibility to enable debug information on a live environment.

	